@@ -4,7 +4,7 @@
 # In[1]:
 
 
-version = '0.30'
+version = '0.33'
 
 import re
 import tempfile
@@ -12,6 +12,7 @@ import os
 import subprocess
 import glob
 from collections import OrderedDict
+import base64
 
 
 # # Helper Functions
@@ -234,6 +235,8 @@ def imread(path):
     return img[:, :, [2, 1, 0]] # This converts the cv2 colors to RGB
 
 def imsread(paths):
+    if os.path.isdir(paths):
+        return [imread(path) for path in fiFindByWildcard(os.path.join(paths, "*.png"))]
     assert isinstance(paths, list) or isinstance(paths, tuple), type(paths)
     return [imread(path) for path in paths]
 
@@ -555,8 +558,6 @@ if is_testing():
 # In[54]:
 
 
-import base64
-
 def jnImgToHtmlB64(img):
     img = imread(img)
     _, encimg = cv2.imencode('.png', img)
@@ -566,7 +567,7 @@ def jnImgToHtmlB64(img):
 
 #def jnHtmlImgsRow(imgs, names=None):
 
-def jnImageTable(imgs, names=None, width=100):
+def jnImageRow(imgs, names=None, width=100):
     _row = lambda x: '<tr>' + x + '</tr>'
     _col = lambda x: '<td style="text-align:center">' + x + '</td>'
     _cols = lambda x: "".join(map(_col, x))
@@ -578,11 +579,11 @@ def jnImageTable(imgs, names=None, width=100):
     display(HTML(html))
 
 
-# In[55]:
+# In[79]:
 
 
 if is_testing():
-    jnImageTable(imgs=[imNewBlack(20, 20), imNewBlack(40, 20), imNewBlack(20, 800)], names=["a", "b", "c"])
+    jnImageRow(imgs=[imNewBlack(20, 20), imNewBlack(40, 20), imNewBlack(20, 800)], names=["a", "b", "c"])
    
 
 
@@ -591,7 +592,7 @@ if is_testing():
 
 
 if is_testing():
-   jnImageTable(imgs=[imNewBlack(20, 20), imNewBlack(40, 20), imNewBlack(20, 800)])
+   jnImageRow(imgs=[imNewBlack(20, 20), imNewBlack(40, 20), imNewBlack(20, 800)])
 
 
 # # Shell
